@@ -119,7 +119,7 @@ class LazyImgArray(AxesMixin):
     @property
     def GB(self) -> float:
         """Return the array size in GB."""
-        return self.value.nbytes / 1e9
+        return self.value.nbytes / 2**30
     
     gb = GB  # alias
     
@@ -1302,8 +1302,9 @@ class LazyImgArray(AxesMixin):
         dims: Dims = None,
         **kwargs,
     ) -> LazyImgArray:
+        import dask.array as da
         pad_width = _misc.make_pad(pad_width, dims, self.axes, **kwargs)
-        padimg = np.pad(self.value, pad_width, mode, **kwargs)
+        padimg = da.pad(self.value, pad_width, mode, **kwargs)
         return padimg
     
     @_docs.copy_docs(ImgArray.wiener)
@@ -1465,8 +1466,8 @@ class LazyImgArray(AxesMixin):
             out = self.__class__(out)
             out._set_info(self)
             return out
-        elif dtype == "int8":
-            out = self.value.astype(np.int8)
+        elif dtype in ("int8", "int16", "int32", "uint32"):
+            out = self.value.astype(dtype)
             out = self.__class__(out)
             out._set_info(self)
             return out
@@ -1497,10 +1498,7 @@ class LazyImgArray(AxesMixin):
         # set additional properties
         # If `other` does not have it and `self` has, then the property will be inherited.
         for p in self.__class__.additional_props:
-            setattr(self, p, getattr(other, p, 
-                                     getattr(self, p, 
-                                             None)))
-    
+            setattr(self, p, getattr(other, p, getattr(self, p, None)))
     
     def _getitem_additional_set_info(self, other, **kwargs):
         self._set_info(other, kwargs["new_axes"])
