@@ -1,13 +1,11 @@
 from __future__ import annotations
 import os
-import sys
 import re
 import glob
 import itertools
 from typing import TYPE_CHECKING, Any, Callable, Iterable, Sequence
-from typing_extensions import Literal
+from typing_extensions import Literal, ParamSpec
 import warnings
-from typing_extensions import ParamSpec
 import numpy as np
 from functools import wraps
 
@@ -552,7 +550,7 @@ def imread(
     
     # read tif metadata
     if not is_memmap:
-        size = os.path.getsize(path) / 1e9
+        size = os.path.getsize(path) / 2**30
         if size > Const["MAX_GB"]:
             raise MemoryError(f"Too large {size:.2f} GB")
 
